
.. _grid_wgs84_fit:

WGS84 Dynamic Fit
^^^^^^^^^^^^^^^^^

:Grid Name: wgs84_fit
:Description: Longitude/Latitude WGS84 Grid
:Projection: EPSG:4326
:Resolution: 0.0057 degrees

.. _grid_wgs84_fit_250:

WGS84 Dynamic Fit 250m
^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: wgs84_fit_250
:Description: Longitude/Latitude WGS84 Grid at ~250m resolution
:Projection: EPSG:4326
:Resolution: 0.00225 degrees

.. _grid_lcc_fit:

Lambert Conic Conformal Dynamic Fit
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: lcc_fit
:Description: 1km East CONUS centered lcc grid (alias: lcc_na)
:Projection: +proj=lcc +lat_1=25 +lat_0=25 +lon_0=-95 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 1000.0 meters

.. _grid_lcc_sa:

Lambert Conic Conformal - South America Centered
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: lcc_sa
:Description: 1km South America centered LCC grid
:Projection: +proj=lcc +lat_1=-25 +lat_0=-25 +lon_0=-55 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 1000.0 meters

.. _grid_lcc_eu:

Lambert Conic Conformal - Europe Centered
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: lcc_eu
:Description: 1km Europe centered LCC grid
:Projection: +proj=lcc +lat_1=25 +lat_0=25 +lon_0=15 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 1000.0 meters

.. _grid_lcc_south_africa:

Lambert Conic Conformal - South Africa Centered
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: lcc_south_africa
:Description: 1km South Africa centered LCC grid
:Projection: +proj=lcc +lat_1=-25 +lat_0=-25 +lon_0=25 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 1000.0 meters

.. _grid_lcc_aus:

Lambert Conic Conformal - Australia Centered
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: lcc_aus
:Description: 1km Australia centered LCC grid
:Projection: +proj=lcc +lat_1=-25 +lat_0=-25 +lon_0=135 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 1000.0 meters

.. _grid_lcc_asia:

Lambert Conic Conformal - Asia Centered
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: lcc_asia
:Description: 1km Asia centered LCC grid
:Projection: +proj=lcc +lat_1=25 +lat_0=25 +lon_0=105 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 1000.0 meters

.. _grid_lcc_fit_hr:

High Resolution Lambert Conic Conformal Dynamic Fit
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: lcc_fit_hr
:Description: 400m East CONUS centered LCC grid
:Projection: +proj=lcc +lat_1=25 +lat_0=25 +lon_0=-95 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 400.0 meters

.. _grid_eqc_fit:

Equirectangular Fit
^^^^^^^^^^^^^^^^^^^

:Grid Name: eqc_fit
:Description: 250m Equirectangular grid
:Projection: +proj=eqc +lat_ts=0 +lat_0=0 +lon_0=0 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 250.0 meters

.. _grid_polar_canada:

Polar-Stereographic Canada
^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: polar_canada
:Description: 1km Polar-stereographic Canada centered grid
:Projection: +proj=stere +lat_0=90 +lat_ts=45 +lon_0=-150 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 1000.0 meters

.. _grid_polar_north_pacific:

Polar-Stereographic North Pacific
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: polar_north_pacific
:Description: 400m Polar-stereographic North Pacific centered grid
:Projection: +proj=stere +lat_0=90 +lat_ts=45 +lon_0=-170 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 400.0 meters

.. _grid_polar_south_pacific:

Polar-Stereographic South Pacific
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: polar_south_pacific
:Description: 400m Polar-stereographic South Pacific centered grid
:Projection: +proj=stere +lat_0=-90 +lat_ts=-45 +lon_0=-170 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 400.0 meters

.. _grid_polar_russia:

Polar-Stereographic Russia
^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: polar_russia
:Description: 400m Polar-stereographic Russia centered grid
:Projection: +proj=stere +lat_0=90 +lat_ts=45 +lon_0=50 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 400.0 meters

.. _grid_polar_alaska:

Polar-Stereographic Alaska
^^^^^^^^^^^^^^^^^^^^^^^^^^

:Grid Name: polar_alaska
:Description: 400m Polar-stereographic Alaska centered grid
:Projection: +proj=stere +lat_0=90 +lat_ts=60 +lon_0=-150 +datum=WGS84 +units=m +no_defs +type=crs
:Resolution: 400.0 meters

.. _grid_goes_east_1km:

GOES-East 1km
^^^^^^^^^^^^^

:Grid Name: goes_east_1km
:Description: GOES-East 1km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-75 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]

.. _grid_goes_east_4km:

GOES-East 4km
^^^^^^^^^^^^^

:Grid Name: goes_east_4km
:Description: GOES-East 4km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-75 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]

.. _grid_goes_east_8km:

GOES-East 8km
^^^^^^^^^^^^^

:Grid Name: goes_east_8km
:Description: GOES-East 8km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-75 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]

.. _grid_goes_east_10km:

GOES-East 10km
^^^^^^^^^^^^^^

:Grid Name: goes_east_10km
:Description: GOES-East 10km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-75 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]

.. _grid_goes_west_1km:

GOES-West 1km
^^^^^^^^^^^^^

:Grid Name: goes_west_1km
:Description: GOES-West 1km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-137 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]

.. _grid_goes_west_4km:

GOES-West 4km
^^^^^^^^^^^^^

:Grid Name: goes_west_4km
:Description: GOES-West 4km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-137 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]

.. _grid_goes_west_8km:

GOES-West 8km
^^^^^^^^^^^^^

:Grid Name: goes_west_8km
:Description: GOES-West 8km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-137 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]

.. _grid_goes_west_10km:

GOES-West 10km
^^^^^^^^^^^^^^

:Grid Name: goes_west_10km
:Description: GOES-West 10km Full Disk Grid
:Projection: +proj=geos +sweep=x +lon_0=-137 +h=35786023 +ellps=GRS80 +units=m +no_defs +type=crs
:Extent: [-5434894.885056, -5434894.885056, 5434894.885056, 5434894.885056]
